Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RespondWithJSON ¶
func RespondWithJSON(Response http.ResponseWriter, StatusCode int, Payload interface{})
RespondWithJSON writes a JSON response to the HTTP response writer. Constructs a standardized server response with payload and success flag. Sets the appropriate headers, status code, and writes the JSON data.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.