encryption

package
v1.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 21, 2025 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CompareWithHash

func CompareWithHash(HashedString string, Password string) bool

CompareWithHash verifies a plain text password against a bcrypt hash

func CreateHash

func CreateHash(Password string) (string, error)

CreateHash generates a bcrypt hash from a plain text password

func Decrypt

func Decrypt(encryptedData models.EncryptReturnType, encryptionKey, initializationVector, encryptionType string) (interface{}, error)

Decrypt decrypts AES-encrypted data in CBC mode and returns original data

func Encrypt

func Encrypt(data interface{}, encryptionKey, initializationVector, encryptionType string) (models.EncryptReturnType, error)

Encrypt encrypts data using AES in CBC mode and returns an encoded payload

Types

This section is empty.

Jump to