Documentation
¶
Index ¶
- func CompareWithHash(HashedString string, Password string) bool
- func CreateHash(Password string) (string, error)
- func Decrypt(encryptedData models.EncryptReturnType, ...) (interface{}, error)
- func Encrypt(data interface{}, encryptionKey, initializationVector, encryptionType string) (models.EncryptReturnType, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CompareWithHash ¶
CompareWithHash verifies a plain text password against a bcrypt hash
func CreateHash ¶
CreateHash generates a bcrypt hash from a plain text password
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.