Documentation
¶
Index ¶
- func CheckAndConvertFile(file io.Reader, fileName string) (io.Reader, error)
- func DeleteFile(filename, uploadDirectory string) error
- func DeleteMultipleFiles(filenames []string, uploadDirectory string) error
- func UploadFile(file io.Reader, fileName, uploadDirectory string, convertToWebP bool) (string, error)
- func UploadMultipleFiles(files []io.Reader, fileNames []string, uploadDirectory string, ...) ([]string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckAndConvertFile ¶ added in v1.0.5
CheckAndConvertFile checks if a file is an image and converts it to WebP
func DeleteFile ¶
DeleteFile removes a single file from the specified directory
func DeleteMultipleFiles ¶ added in v1.0.3
DeleteMultipleFiles deletes multiple files and returns error if any deletions fail
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.