json

package
v1.0.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RespondWithJSON

func RespondWithJSON(Response http.ResponseWriter, StatusCode int, Payload interface{})

RespondWithJSON writes a JSON response to the HTTP response writer Constructs a standardized server response with payload and success flag Sets the appropriate headers, status code, and writes the JSON data

Types

This section is empty.

Jump to