Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RespondWithJSON ¶
func RespondWithJSON(Response http.ResponseWriter, StatusCode int, Payload interface{})
RespondWithJSON writes a JSON response to the http.ResponseWriter. Response: The HTTP response writer to send the response. StatusCode: The HTTP status code to indicate the outcome of the request. Payload: The data to be included in the response body.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.