json

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 20, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RespondWithJSON

func RespondWithJSON(Response http.ResponseWriter, StatusCode int, Payload interface{})

RespondWithJSON writes a JSON response to the http.ResponseWriter. Response: The HTTP response writer to send the response. StatusCode: The HTTP status code to indicate the outcome of the request. Payload: The data to be included in the response body.

Types

This section is empty.

Jump to