log

package
v1.2.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2025 License: MIT Imports: 2 Imported by: 1

Documentation

Overview

Package log provides colored logging functions with timestamps.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Error

func Error(message string)

Error logs an error message with a red [ERROR] prefix and timestamp.

func Info

func Info(message string)

Info logs an informational message with a blue [INFO] prefix and timestamp.

func Success

func Success(message string)

Success logs a success message with a green [SUCCESS] prefix and timestamp.

func Warning

func Warning(message string)

Warning logs a warning message with a yellow [WARNING] prefix and timestamp.

Types

This section is empty.

Jump to