Documentation
¶
Overview ¶
Package log provides colored logging functions with timestamps.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Error ¶
func Error(message string)
Error logs an error message with a red [ERROR] prefix and timestamp.
func Info ¶
func Info(message string)
Info logs an informational message with a blue [INFO] prefix and timestamp.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.