models

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 20, 2025 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type EmailDetails

type EmailDetails struct {
	From        string   // Sender email address
	To          []string // Recipient email addresses
	Subject     string   // Email subject
	Text        string   // Plain text message
	HTML        string   // HTML message
	Attachments []string // Paths to files to attach
}

EmailDetails holds the necessary information for sending an email.

type EncryptReturnType

type EncryptReturnType struct {
	Payload string
}

EncryptReturnType defines the return type of the encryption function.

type SMSMessageData

type SMSMessageData struct {
	Message    string         `json:"Message"`
	Recipients []SMSRecipient `json:"Recipients"`
}

type SMSPayload

type SMSPayload struct {
	Username     string   `json:"username"`
	Message      string   `json:"message"`
	SenderID     string   `json:"senderId"`
	PhoneNumbers []string `json:"phoneNumbers"`
	ATAPIKey     string   `json:"apiKey"`
}

type SMSRecipient

type SMSRecipient struct {
	StatusCode int    `json:"statusCode"`
	Number     string `json:"number"`
	Status     string `json:"status"`
	Cost       string `json:"cost"`
	MessageID  string `json:"messageId"`
}

type SMSResponse

type SMSResponse struct {
	SMSMessageData SMSMessageData `json:"SMSMessageData"`
}

type ServerResponse

type ServerResponse struct {
	Success bool        `json:"success"` // Indicates whether the operation was successful.
	Message interface{} `json:"message"` // Contains the response message or payload.
}

ServerResponse represents the structure of the JSON response. Success indicates whether the operation was successful. Message contains the response message or payload (could be string, object, etc.).

Jump to