Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EmailDetails ¶
type EmailDetails struct {
From string // Sender email address
To []string // Recipient email addresses
Subject string // Email subject
Text string // Plain text message
HTML string // HTML message
Attachments []string // Paths to files to attach
}
EmailDetails holds the necessary information for sending an email.
type EncryptReturnType ¶
type EncryptReturnType struct {
Payload string
}
EncryptReturnType defines the return type of the encryption function.
type SMSMessageData ¶
type SMSMessageData struct {
Message string `json:"Message"`
Recipients []SMSRecipient `json:"Recipients"`
}
type SMSPayload ¶
type SMSRecipient ¶
type SMSResponse ¶
type SMSResponse struct {
SMSMessageData SMSMessageData `json:"SMSMessageData"`
}
type ServerResponse ¶
type ServerResponse struct {
Success bool `json:"success"` // Indicates whether the operation was successful.
Message interface{} `json:"message"` // Contains the response message or payload.
}
ServerResponse represents the structure of the JSON response. Success indicates whether the operation was successful. Message contains the response message or payload (could be string, object, etc.).
Click to show internal directories.
Click to hide internal directories.