request

package
v1.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2025 License: MIT Imports: 6 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get(url string, headers *Headers) (json.RawMessage, error)

Get sends an HTTP GET request to the specified URL Applies headers and returns the response body as json.RawMessage

func Post

func Post(url string, body any, headers *Headers) (json.RawMessage, error)

Post sends an HTTP POST request with a JSON body to the specified URL Applies headers and returns the response body as json.RawMessage

Types

type Headers

type Headers map[string]string

Headers type alias for map[string]string

Jump to