Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StartServer ¶
func StartServer(ctx context.Context, handler http.Handler, port, sslKeyPath, sslCertPath string) error
StartServer starts an HTTP or HTTPS server with graceful shutdown support. Uses the provided hanlder and port, and supports TLS for Production mode. Returns an error if the server fails to start or encounters issues during operation.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.