server

package
v1.0.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func StartServer

func StartServer(ctx context.Context, router *chi.Mux, port, SSLKeyPath, SSLCertPath string) error

StartServer initializes and starts an HTTP or HTTPS server with graceful shutdown Runs the server based on the environment and handles context cancellation Returns an error if the server fails to start or encounters issues

Types

This section is empty.

Jump to