Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StartServer ¶
StartServer initializes and starts an HTTP or HTTPS server with graceful shutdown Runs the server based on the environment and handles context cancellation Returns an error if the server fails to start or encounters issues
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.