package
Version:
v1.0.5
Opens a new window with list of versions in this module.
Published: May 13, 2025
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func StartServer(Router *chi.Mux, PORT, SSLKeyPath, SSLCertPath string)
StartServer initializes and starts an HTTP or HTTPS server
Configures the server based on the environment and starts it
Source Files
¶
Click to show internal directories.
Click to hide internal directories.